#
# spec file for package gnuplot
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           gnuplot
BuildRequires:  cairo-devel emacs-nox freetype2-devel gcc-c++ gd-devel gtk2-devel latex2html libjpeg-devel netpbm pango-devel readline-devel texlive-latex xorg-x11 xorg-x11-devel
%if %suse_version > 1130
BuildRequires:  wxWidgets-devel
%else
BuildRequires:  wxGTK-devel
%endif
%if 0%{?suse_version} > 1120
BuildRequires:  libpng14-devel lua-devel
%else
BuildRequires:  libpng-devel
%endif
%if 0%{?suse_version} > 1110
BuildRequires:  plotutils-devel
%else
BuildRequires:  plotutils
%endif
Url:            http://www.gnuplot.info/
License:        BSD3c(or similar)
Group:          Productivity/Graphics/Visualization/Graph
AutoReqProv:    on
Version:        4.4.2
Release:        4.8.sles11.lc
Summary:        GNUplot a Function Plotting Utility
Source0:        gnuplot-%{version}.tar.bz2
Source2:        gnuplot-fr.doc.bz2
Source3:        README.whynot
Patch0:         gnuplot-4.4.1.dif
Patch1:         gnuplot-4.4.0-x11ovf.dif
Patch2:         gnuplot-4.4.0-fonts.dif
Patch3:         gnuplot-4.4.0-wxt.dif
Patch4:         gnuplot-4.4.0-demo.dif
Patch6:         gnuplot-4.2.5-fix-format-errors.dif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{expand: %%global _exec_prefix %(type -p pkg-config &>/dev/null && pkg-config --variable prefix x11 || echo /usr/X11R6)}
%if "%_exec_prefix" == "/usr/X11R6"
%define _x11lib     %{_exec_prefix}/%{_lib}
%define _x11data    %{_exec_prefix}/lib/X11
%define _libx11     %{_x11data}
%define _x11inc     %{_exec_prefix}/include
%define _appdef     %{_x11data}/app-defaults
%else
%define _x11lib     %{_libdir}
%define _x11data    %{_datadir}/X11
%define _libx11     %{_exec_prefix}/lib/X11
%define _x11inc     %{_includedir}
%define _appdef     %{_x11data}/app-defaults
%endif
%if %suse_version > 1130
%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
%endif

%description
GNUplot is a command line driven interactive function plotting utility.
 GNUplot supports many different types of terminals, plotters, and
printers (including many color devices and pseudodevices like LaTeX)
and can easily be extended to include new devices.

%package doc
License:        BSD3c(or similar)
Summary:        Documentation of GNUplot
Group:          Productivity/Graphics/Visualization/Graph
Requires:       %{name}
Requires(post): %install_info_prereq
Requires(postun): %install_info_prereq
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description doc
GNUplot documentation files including the man and info pages. GNUplot
is a command line driven interactive function plotting utility. 
GNUplot supports many different types of terminals, plotters, and
printers (including many color devices and pseudodevices like LaTeX)
and can easily be extended to include new devices.

%{name} documentation files including the man and info pages

%prep
%setup -q -n gnuplot-%{version}
bunzip2 -dc %{_sourcedir}/gnuplot-fr.doc.bz2 > docs/gnuplot-fr.doc
test $? -eq 0 || exit 1
%patch -P 1 -p 0 -b .x11ovf
%patch -P 2 -p 0 -b .font
#%patch -P 3 -p 0
%patch -P 4 -p 0
%patch -P 6 -p 0
%patch -P 0 -p 0

%build
    SECSVGA="-DSVGA_IS_SECURE=1"
    export  CPPFLAGS="-I%{_x11inc} -I%{_includedir}/gd -DAppDefDir=\\\"%{_appdef}\\\""
    export  CPPFLAGS="$CPPFLAGS -DGNUPLOT_LIB_DEFAULT=\\\"%{_docdir}/%{name}/demo\\\""
    export  CFLAGS="${RPM_OPT_FLAGS} -pipe ${SECSVGA} -D_GNU_SOURCE"
    export  CXXFLAGS="$CFLAGS -fno-strict-aliasing"
    export  LDFLAGS="-L%{_x11lib} -Wl,--as-needed"
    export  ARCHLIB=%_lib
    for f in docs/makefile*; do
	test -e $f || continue
	mv $f $f.bak
    done
    touch configure.in
    rm -f config.status config.log config.cache configure aclocal.m4
    aclocal -I m4
    autoconf
    ./configure			\
	--prefix=%{_prefix}	\
	--mandir=%{_mandir}	\
	--infodir=%{_infodir}	\
	--libexecdir=%{_libdir}	\
	--datadir=%{_datadir}	\
	--with-gcc		\
	--with-x		\
	--x-includes=%{_x11inc}	\
	--x-libraries=%{_x11lib}\
	--with-x-app-defaultdir=%{_appdef}\
	--with-readline=gnu	\
	--enable-history-file	\
	--with-linux-vga	\
	--with-gif=png		\
	--with-freetype=%{_libdir}\
	--enable-x11-mbfonts	\
	--enable-h3d-quadtree	\
	--with-zlib		\
	--with-gd		\
	--enable-thin-splines	\
	--without-row-help	\
	--with-kpsexpand	\
	--with-plot=%{_libdir}
    make %{?jobs:-j%jobs}
    pushd docs/
	make srcdir=. clean all html pdf gpcard.ps
	pushd psdoc/
	    make srcdir=. clean pdf
	popd
    popd
    pushd tutorial/
	make srcdir=. clean pdf
    popd

%install
    rm -rf %{buildroot}
    make DESTDIR=%{buildroot} appdefaultdir=%{_appdef} install
    mkdir -p %{buildroot}/%{_infodir}
    mkdir -p %{buildroot}/%{_docdir}/gnuplot/doc
    mkdir -p %{buildroot}/%{_docdir}/gnuplot/doc/html
    mkdir -p %{buildroot}/%{_docdir}/gnuplot/demo
    rm  -vf docs/htmldocs/images.{aux,idx,log,out,tex}
    rm  -vf docs/htmldocs/*.pl
    rm  -vf docs/htmldocs/*.sty
    rm  -vf docs/htmldocs/WARNINGS
    rm  -vf docs/htmldocs/VERSION
    rm -rvf demo/html
    install -m 0444 docs/*.info*      %{buildroot}/%{_infodir}/
    install -m 0444 docs/*.pdf        %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 docs/gpcard.ps    %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 docs/htmldocs/*   %{buildroot}/%{_docdir}/gnuplot/doc/html
    install -m 0444 docs/psdoc/*.pdf  %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 docs/psdoc/*.ps   %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 docs/psdoc/*.gpi  %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 docs/psdoc/*.doc  %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 docs/psdoc/README %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 tutorial/*.pdf    %{buildroot}/%{_docdir}/gnuplot/doc/
    install -m 0444 demo/*            %{buildroot}/%{_docdir}/gnuplot/demo/
    install -m 0444 README*           %{buildroot}/%{_docdir}/gnuplot/
    install -m 0444 Copyright         %{buildroot}/%{_docdir}/gnuplot/
    install -m 0444 TODO VERSION      %{buildroot}/%{_docdir}/gnuplot/
    install -m 0444 NEWS BUGS	      %{buildroot}/%{_docdir}/gnuplot/
    install -m 0444 %{SOURCE3}        %{buildroot}/%{_docdir}/gnuplot/
    rm -f %{buildroot}/%{_docdir}/gnuplot/demo/Makefile*
    rm -f %{buildroot}/%{_datadir}/emacs/site-lisp/info-look.*

%clean
    rm -rf %{buildroot}

%post doc
%install_info --info-dir=.%{_infodir} .%{_infodir}/%{name}.info.gz

%postun doc
%install_info_delete --info-dir=.%{_infodir} .%{_infodir}/%{name}.info.gz

%files
%defattr(-,root,root)
%{_bindir}/gnuplot
%{_libdir}/gnuplot
%{_datadir}/gnuplot
%{_datadir}/texmf/tex/latex/gnuplot/
%{_datadir}/emacs/site-lisp/
%{_appdef}/Gnuplot

%files doc
%defattr(-,root,root,-)
%doc %{_docdir}/gnuplot/
%doc %{_infodir}/%{name}.info.gz
%doc %{_mandir}/man1/gnuplot.1.gz

%changelog
* Wed Dec 29 2010 sbrabec@suse.cz
- Compile with wxWidgets (STL variant).
* Thu Sep 30 2010 burnus@net-b.de
- Update to gnuplot 4.4.2
  * Fixes a regression that caused color specification "lc N" to fail
  * Fixes a long-standing clipping error in plots with filled curves
  * Fixes a segfault if a "refresh" commands follows an interrupted replot
  Changes and fixes in gnuplot version 4.4.1:
  * NEW Support the "%%s" format specifier in strftime()
  * NEW Optional 6th data column in candlesticks style to specific box width
  * NEW If integer arithmetic i*j or i**j would overflow, return value as a real
  * NEW "set style circle radius <default-radius>"
  * FIX autoconfiguration of readline support in OSX
  * FIX font problems in win terminal
  * FIX Protect against runaway recursion by limiting depth of nested functions
  * FIX metapost terminal: Fix inheritance of line thickness by text strings
  * FIX cairo terminals could segfault on certain enhanced text strings
  * FIX pdfcairo output to stdout now works
  * FIX font ",size" in non-enhanced mode postscript terminals
  * FIX Do a better job of estimating the width of UTF-8 encoded strings
  * FIX baseline bug in canvas terminal rotation of enhanced text
  * FIX Allow "with labels" to work for binary input data
  * FIX update user GPVAL variables after plot in table mode
  * CHANGE depth-sorting of pm3d surfaces now applies jointly to all in the plot
  * CHANGE 3D impulses are now always drawn from z=0
  * CHANGE Enable HIDDEN_QUADTREE by default
  * CHANGE Enable "set fit errorvariables" by default
  * CHANGE Regardless of current timefmt, read time from binary files as a binary
  * CHANGE do not limit 3D rotation to 0<rotx<180
* Tue Sep 14 2010 werner@suse.de
- Make doc package noarch
* Tue Sep 14 2010 werner@suse.de
- Update to gnuplot 4.4.0
  * NEW Support the "%%s" format specifier in strftime()
  * NEW Optional 6th data column in candlesticks style to specific box width
  * NEW If integer arithmetic i*j or i**j would overflow, return value as a real
  * NEW "set style circle radius <default-radius>"
  * FIX autoconfiguration of readline support in OSX
  * FIX font problems in win terminal
  * FIX Protect against runaway recursion by limiting depth of nested functions
  * FIX metapost terminal: Fix inheritance of line thickness by text strings
  * FIX cairo terminals could segfault on certain enhanced text strings
  * FIX pdfcairo output to stdout now works
  * FIX font ",size" in non-enhanced mode postscript terminals
  * FIX Do a better job of estimating the width of UTF-8 encoded strings
  * FIX baseline bug in canvas terminal rotation of enhanced text
  * FIX Allow "with labels" to work for binary input data
  * FIX update user GPVAL variables after plot in table mode
  * CHANGE depth-sorting of pm3d surfaces now applies jointly to all in the plot
  * CHANGE 3D impulses are now always drawn from z=0
  * CHANGE Enable HIDDEN_QUADTREE by default
  * CHANGE Enable "set fit errorvariables" by default
  * CHANGE Regardless of current timefmt, read time from binary files as a binary
  * CHANGE do not limit 3D rotation to 0<rotx<180
* Thu May 20 2010 werner@suse.de
- Correct macro name in spec file
* Tue May 18 2010 dieter.jurzitza@t-online.de
- Fix format being written into plt files (add missing #)
* Sat May  8 2010 dieter.jurzitza@t-online.de
- Fix AppDefDir vs. XAPPLRESDIR inconsistency, increase default number of samples.
* Wed Apr  7 2010 werner@suse.de
- Update to gnuplot 4.4.0
  * NEW linetype property 'pointinterval'
  * NEW gnuplot.exe is a full-featured console mode gnuplot executable for Windows
  * NEW plot style "with circles"
  * NEW object types circle, ellipse, and polygon
  * NEW options front and back to "set colorbox"
  * NEW x11 can plot into a window opened and managed by an external application
  * NEW gd terminal can use fonts through fontconfig (libgd version > 2.0.35)
  * NEW optional 3 columns of data to generate histogram errorbars
  * NEW 'volatile' data, including inline data, can be replotted without rereading
  * NEW 'refresh' command replots without rereading data if possible
  * NEW rgbimage style now works in 2D and 3D for all terminals that support RGB
  * NEW plot style rgbalpha
  * NEW transparent fill styles
  * NEW iteration within a plot command; e.g. plot for [i=1:10] foo(i)
  * NEW iteration within set/unset commands
  * NEW operators '=' and ',' in expression syntax
  * NEW terminal lua generates commands for interpretation by external lua script
  * NEW terminal tikz uses a lua script to generate output for latex TikZ package
  * NEW terminal canvas for HTML 5 canvas element
  * NEW terminal pdfcairo based on cairo and pango
  * NEW terminal pngcairo based on cairo and pango
  * NEW terminal dpu414 - Seiko DPU-414 thermal printer
  * NEW error status variables GPVAL_ERRNO and GPVAL_ERRMSG
  * NEW variables GPVAL_LAST_PLOT, GPVAL_{S}PLOT, GPVAL_MULTIPLOT
  * NEW variables GPVAL_VIEW_{MAP|ROT_X|ROT_Z|SCALE|ZSCALE}, GPVAL_TERMINALS
  * NEW variables GPVAL_PWD
  * NEW per-plot export of information needed for external mousing scripts
  * NEW support for dashed linetypes in additional terminals
  * NEW the 'bind' command accepts non-keyboard triggers, e.g. 'close'
  * NEW commands 'show bind' and 'reset bind'
  * NEW individual plots can be omitted from autoscaling of axis ranges
  * NEW more smoothing options: new kernels (for dgrid3d) and 'smooth cumulative'
  * NEW command 'evaluate' executes commands from a string variable
  * NEW z-axis tic labels can be colored by Z value
  * NEW command 'set view equal {xy|xyz}' forces axes in a 3D plot to the same scale
  * NEW 'set pm3d interpolate m,n' supports also non-positive m,n as nbs of points
  * FIX domain restrictions on ibeta()
  * FIX color assignment of contour lines when "set increment user" is in effect
  * FIX remove the limit of 64 characters read as string data from a data file
  * FIX remainder of command line is not lost after a "load" command
  * FIX more complete support for locale internationalization, UTF-8 encoding
  * FIX various font-handling problems in postscript terminal driver
  * FIX avoid infinite loop on resizing x11 plot window under ion, fluxbox
  * FIX handle addition plot styles in mode 'set table'
  * FIX purge tick labels read from a datafile at the end of each plot
  * FIX 2nd colour in the colour box for negative palette in postscript
  * FIX interpolatation for pm3d surfaces given by both z and colour coordinates
  * FIX 'set datafile binary format=...' was documented, but not implemented
  * FIX enhanced text mode treatment of UTF-8 characters
  * FIX emf terminal enhanced text mode now accepted by Windows programs
  * CHANGE A number that begins with a . must continue with a digit
  * CHANGE syntax of 'set datafile binary' array= and record= options
  * CHANGE 'reset' does not affect locale, encoding, decimalsign settings
  * CHANGE 'set key textcolor rgb variable' will use plot colors for key entries
  * CHANGE Remove obsolete IRIS4D terminal type
  * CHANGE Remove obsolete atari terminal types (atariaes atarivdi multitos)
  * CHANGE Use empty/solid fill for candlesticks rather than empty/striped
  * CHANGE 'l' and 'L' hotkeys toggle colorbar logscale iff mouse is in colorbar
* Thu Mar  4 2010 coolo@novell.com
- fix compilation with gcc 4.5
- update to gnuplot 4.2.6
  * NEW xterm tektronix emulation 'set term xterm'
  * FIX 'set xtics mirror' didn't work if xtics were previously unset
  * FIX off-by-one pixel bug in width of boxes with palette or rgb color
  * FIX center rotation of 'set view equal xyz' mode at screen center
  * FIX sanity-check time ranges for axes with timeformat
  * FIX pslatex blacktext and broken format specifier
  * FIX PostScript code points for Lcaron, lcaron in encoding cp1250
  * CHANGE If a 2D plot uses a Z-based palette, then autoscale cbrange
  * CHANGE aquaterm accepts "size xx,yy" with a comma
  * CHANGE Remove the EXPERIMENTAL flag from the wxt terminal
  * CHANGE Remove the EXPERIMENTAL flag from the x11 terminal binary polygon mode
* Mon Jun 22 2009 werner@suse.de
- Remove obsolate code for GNUPLOTDEMOPATH (bnc#515001)
- Add emacs lisp files to file list (bnc#515001)
* Mon Jun 15 2009 werner@suse.de
- Make demos more flexible (hint from dieter.jurzitza@t-online.de)
- Add netpbm and xorg-x11 to build requires or jpg's are zero
* Tue May 26 2009 werner@suse.de
- Update changes file
* Sat May  9 2009 @gmx.de
- update to gnuplot 4.2.5
- put docs into gnuplot-doc sub-package
* Thu Jan 15 2009 sbrabec@suse.cz
- Changed BuildRequires: plotutils -> plotutils-devel.
* Mon Mar 31 2008 werner@suse.de
- Make gnupplot UTF-8 capable (bnc#375175)
* Wed Mar 26 2008 werner@suse.de
- Update to gnuplot 4.2.3
  * NEW options front and back to "set colorbox"
  * NEW character encoding support for emf and pdf terminals
  * NEW "format" keyword for "set tics" and "set {x|y|...}tics"
  * NEW allow user to set colorbar label rotatation if the bar is vertical
  * FIX allow tic format to be given as a string variable
  * FIX handling of negative screen coordinates on ia64, PPC
  * FIX coloring of hidden surfaces if drawn with line styles
  * FIX direction of y axis in graph coords for "set view map"
  * FIX minitics in log scale
  * FIX minor bugfixes to terminals fig, emf, post, svg, x11
  * FIX cgm terminal now produces correct pm3d and pattern fill output
  * FIX protect against overly long font names in gd, svg
  * FIX infinite loop from x11 plot window resizing under ion, fluxbox
  * FIX never estimate zero size for a non-empty string
  * FIX discard degenerate polygons during hidden3d processing
  * FIX segfault if replot is called while terminal type is unknown
  * FIX segfault if locale obtained by getenv() is freed
  * FIX discard axis ticks read from previous data file
  * FIX Do not clip image against Z range in 3D splot with "set view map"
  * FIX off-by-one error in implicit column 0 for binary data files
  * FIX splot was trashing the default clipping boundaries for 2D plots
  * CHANGE tweak installation scripts for OSX nt cyg dj2 mgw
  * CHANGE install Xresource file as Gnuplot, not Gnuplot.app-defaults
  * CHANGE Remove limitation of 10 args max to internal function sprintf()
  * CHANGE Bring emf point types into conformity with other terminals
  * CHANGE estimate the vertical space for rotated tick labels on x and x2 axes
* Fri Mar 14 2008 werner@suse.de
- Disable warning about missing character set to avoid bnc#369156
* Fri Dec 14 2007 werner@suse.de
- Update to gnuplot 4.2.2
  * FIX Axis labels were ignored in mode "set view map"
    Candlesticks did not receive the border color specified in fillstyle
  * NEW allow extra column in 2D plots containing color information
  * NEW set term latex {size XX,YY}
  * FIX buffering of very long input lines
  * FIX clipping of image data against plot boundary
  * FIX polygon clipping bugs
  * FIX key sample for plots with variable color
  * FIX wxt initialization on non-gnu systems
  * FIX escape sequence %%%% handling in sprintf() format strings
  * FIX Apply "set style incr user" to 3D contours and to columnstacked histograms
  * FIX Apply "set key {no}enhanced" to key titles read from a file
  * FIX Allow string variable as filename for "fit via <filename>"
  * CHANGE defer x11 initialization until first plot command
  * CHANGE clean up configuration files for amg, cyg, mgw, dj2
  * CHANGE modify SVG output to accommodate non-compliant viewers
  * CHANGE allow 'strcol()' as shorthand for 'stringcolumn()'
  * CHANGE default to "blacktext" for TeX-based PostScript variants
* Wed Sep  5 2007 werner@suse.de
- Correct name of app-defaults file
- Make samples in demo directory usable from any path
  thanks goes to Dieter Jurzitza
* Wed May 30 2007 werner@suse.de
- Overwrite empty default font for UTF-8 locale (bug #277876)
- Get html docs fully build and installed
- Correct datadir
- The patent of gif is expired
* Fri May 11 2007 werner@suse.de
- Use setlocale(..,NULL) instead of gentenv() (bug #272915)
* Tue Apr 24 2007 werner@suse.de
- Enable new but experimental wxt terminal (bug #266693)
* Fri Apr 20 2007 aj@suse.de
- Use texlive for Building.
* Thu Apr  5 2007 werner@suse.de
- Update to gnuplot 4.2.0
  * NEW autogenerated read-only variables prefixed GPVAL_ and "show variables all"
  * NEW Japanese language documentation - FAQ and User Manual
  * NEW multi-platform and interactive wxWidgets terminal
  * NEW windows terminal supports enhanced text mode
  * NEW support for placement of individual rectangles within plot or canvas
  * NEW command "set style increment user" allows customization of default lines
  * NEW commands raise and lower
  * NEW y and y2 axis label rotation can be explicitly controlled (2D plots only)
  * NEW {no}enhanced flag can be applied to individual labels
  * NEW suboption 'set pm3d interpolate' for bilinear interpolation of surfaces
  * NEW 3D plots can read RGB color triples as part of input data
  * NEW write command history file also for gnuplot's readline
  * NEW more versatile key placement and arrangement
  * NEW 'splot x*y with pm3d' no longer requires prior 'set pm3d'
  * NEW store a sequence of plots to an animated gif (requires libgd > 2.0.28)
  * NEW multi-byte font support in x11, controlled by the locale setting LC_CTYPE
  * NEW control decimal sign conventions using locale setting LC_NUMERIC
  * NEW pstex, pslatex and epslatex terminals share functionality with postscript
  * NEW suboptions "set pm3d corners2color min|max"
  * NEW suboption  "set pm3d depthorder" does hidden-surface removal (sort of)
  * NEW linetype colors via "lt {palette {frac <val> | cb <val>}}"
  * NEW linetype colors via "lt {rgbcolor {"name" | "#RRGGBB"}}"
  * NEW palette and rgb linetype colors apply to all 2D and 3D plot elements
  * NEW user defined variables can contain strings
  * NEW expression evaluation can manipulate and return strings
  * NEW built-in string functions sprintf, gprintf, substr, strstrt, word, words
  * NEW built-in string function system("shell command")
  * NEW command line macro expansion   @<stringvariablename>
  * NEW automatic variable $# expanded to number of arguments after "call"
  * NEW reading of (almost) arbitrary image binary files
  * NEW plot styles "with image" and "with rgbimage"
  * NEW plot style "with labels" reads text data along with X/Y/Z coordinates
  * NEW plot style "with histograms" creates clustered or stacked histograms
  * NEW auto-layout of multiplot using "set multiplot layout <rows>, <cols>"
  * NEW variant of plot "with filledcurves" that fills the area between two curves
  * NEW variant of "with filledcurves" that fills only above or below the curve
  * NEW using options {x|y|z}ticlabels(<col>)
  * NEW option to read plot title from data file: set key autotitle columnheader
  * NEW command 'set termoption <foo>' changes single property of current terminal
  * NEW png driver supports antialiasing and TrueColor images
  * NEW encoding koi8-u
  * NEW plot style "with vectors" applies to both 2D and 3D plots
  * NEW plot style "with points" can read variable point size from input file
  * NEW "set tics" can change most settings for {x|y|z|cb}tics at once
  * NEW tic scale can be set per axis using "set {x|y|z|cb}tics scale"
  * CHANGE history file is written by default
  * CHANGE PostScript prolog and character encoding files now maintained separately
  * CHANGE Placement of z-axis label in 3D plots is now equivalent to x and y axes
  * CHANGE "set ticsscale" is deprecated, use "set tics scale" instead
  * CHANGE gnuplot on x11 has mousing always enabled on startup
  * CHANGE 'set datafile fortran' is now required in order to read D or Q constants
  * CHANGE let the string in '{s}plot ... notitle "string"' be silently ignored
  * CHANGE libgd versions 2.0.28+ support GIF images as well as PNG/JPEG
  * CHANGE remove old (non-libgd) GIF and PNG drivers
  * CHANGE X-resource gnuplot*ctrlq:on requires <ctrl>q to kill plot window
  * CHANGE X-resource gnuplot*exportselection:off disables plot->clipboard export
  * CHANGE prefer use of offset keyword in 'set [xyz]label "foo" offset -1,-1'
  * CHANGE 'set table "outfile"; ...; unset table' replaces 'set term table'
  * CHANGE 'defined(foo)' is deprecated; new syntax is 'exists("foo")'
  * FIXED empty datafiles are not a fatal error
  * FIXED setenv GNUTERM now works for png, jpeg, and gif drivers
  * FIXED PostScript output can be restricted to Level 1 compatible features
  * FIXED emf output is compatible with MSWin XP SP 2
  * FIXED limit size of X11 requests to half the maximum allowed by the X display
  * FIXED arrowheads drawn in solid lines even if the shaft is dotted (PostScript)
  * FIXED estimate true effective length of strings in enhanced text mode
  * FIXED clipping of filled curves
* Wed Aug 16 2006 sndirsch@suse.de
- gnuplot-4.0.0-fonts.dif: fixed font paths for X.Org 7
* Tue Jan 31 2006 werner@suse.de
- Fix stupid buffer overflow in x11 display program (bug #146870)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul 21 2005 werner@suse.de
- Re-use libgd because we get jpeg/png support with truetype font
  and gif dummy support which is png output for term gif (#97208)
* Thu Feb 10 2005 ro@suse.de
- remove dropped tetex subpackages from nfb
* Thu Apr 29 2004 werner@suse.de
- Use GNU readline library
- Enable thin splines for 3D
* Tue Apr 27 2004 werner@suse.de
- Update to gnuplot 4.0.0
* Tue Apr 20 2004 meissner@suse.de
- aliasing fixes.
* Thu Oct 16 2003 meissner@suse.de
- Do not build as root.
- Fixed lib64 handling to be more correct, since 32bit systems
  can now have /lib64/ too.
* Fri Jun 13 2003 coolo@suse.de
- fixing docs installation
* Thu Jun 12 2003 coolo@suse.de
- use BuildRoot
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Mar 25 2003 werner@suse.de
- Make mouse patch work as it should
* Mon Mar 24 2003 werner@suse.de
- Update to gnuplot 3.7.3
- Port patches (if needed) to 3.7.3
* Fri Feb 28 2003 werner@suse.de
- Fix bug #23417: use intall-info for info file
* Fri Nov 22 2002 werner@suse.de
- Fix buffer overflow
- Fix svgalib handling for secure svgalibs
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Mon May  6 2002 werner@suse.de
- Do some lib64 stuff
* Thu Apr  4 2002 ro@suse.de
- more brackets for autoconf
* Sun Feb 10 2002 ro@suse.de
- tar option for bz2 is now "j"
* Fri Feb  1 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Jan  9 2002 ro@suse.de
- fixed to compile (don't include fcntl when building the help)
* Sat Jan  5 2002 kukuk@suse.de
- fix neededforbuild (plotutil -> plotutils)
* Tue Dec 18 2001 werner@suse.de
- Be sure that the waitforinput function is called even if real
  readline library is used or none interactive mode is on.  Be sure
  that the buffered token will be handles even if there is no
  activity on stdin and set a time out to be not blocked (#12625)
* Mon Nov 12 2001 ro@suse.de
- no svgalib
* Tue Jun 12 2001 schwab@suse.de
- Fix for new autoconf.
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Thu Mar 29 2001 garloff@suse.de
- Prevent stupid rounding errors 10*10^23 instead of 10^24
  in graphics.c: mant_exp()
* Fri Feb 23 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Sun Dec  3 2000 schwab@suse.de
- Fix resource leak in X11 terminal driver.
* Wed Jun 21 2000 werner@suse.de
- Add French doc (somewhat out of date)
* Wed Jun  7 2000 werner@suse.de
- New version 3.7.1 with many bug fixes included
* Tue Jun  6 2000 uli@suse.de
- moved docs to /usr/share/doc
* Fri Feb 25 2000 kukuk@suse.de
- Move /usr/{info,man} -> /usr/share/{info,man}
* Mon Oct 11 1999 ro@suse.de
- disabled gdlib support (we have png anyway and gd doesn't support
  gif any more)
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon May  3 1999 werner@suse.de
- Do not use system time because gnuplot interface isn't able
    to handle summer time
  - Use /tmp/ for temporaray files of demos
* Wed Mar 10 1999 werner@suse.de
- Fix from one of the authors (HBB) to avoid buffer overflow
* Tue Mar  9 1999 werner@suse.de
- New patchlevel 0.1 with patch gnuplot.990304 for security
* Tue Mar  2 1999 werner@suse.de
- New version: 3.7
  * add some official fixes
  * fix the official fix of fit.c
  * add gif and unixplot for output
* Sun Aug 23 1998 bs@suse.de
- fixed "neededforbuild"
* Mon Jul 13 1998 werner@suse.de
- New version: 3.5beta6.347
  * Security fix for svga linux driver call
  * Some enhancements
  * Some bug fixes
* Thu Oct 23 1997 werner@suse.de
- New version: 3.5beta6.336
* Mon Feb  3 1997 werner@suse.de
- Update auf Version 3.5-beta-3.6pl319
  - Diese Version hat splines und bezier zum Fit fr
    von Messdaten.
  - verschoben von ap1 -> xap1
* Thu Jan  2 1997 werner@suse.de
- Neu Erstellen des Paketes:
    Mit vollstndiger Dokumentation und Beispielen
    unter /usr/doc/packages/gnuplot/
  - fig und bfig (xfig-Format 2.1)
    wird von xfig in xfig-Format 3.2 konvertiert.
